@@ -370,6 +370,12 @@ $page = 0;
  **********************************************************/
 function exec_dhcp_search($post, &$data, &$result)
 {
+
+    global $web_conf;
+    global $msgarr;
+    global $err_msg;
+    global $log_msg;
+
     $ret = check_dhcp_search_condition($post);
 
     if ($ret === FALSE) {
@@ -381,26 +387,71 @@ function exec_dhcp_search($post, &$data, &$result)
     if ($conn === FALSE) {
         return(2);  
     }
-    /*DHCPSQL*/
-    $ret = make_dhcp_search_sql($conn, $post, $search_sql);
-    if ($ret === 1) {
-        /*MySQL_exec_query*/
-        mysqli_close($conn);
-        return(1);
-    }
 
-    /*MySQL*/
-    $result = MySQL_exec_query($conn, $search_sql);
-    $err_num = 0;
-    if ($result === FALSE) {
-        $err_num = mysqli_errno($conn);
-        mysqli_close($conn);
-        return(2);
-    }
+    /* פ "MYSQL" ξ */
+    if ($web_conf['sylas']['searchtype'] === MYSQL) {
 
-    /*MySQLϿ줿ơ֥ξ˳Ǽ*/
-    MySQL_get_data($result, $data);
-    mysqli_close($conn);
+        /*DHCPSQL*/
+        $ret = make_dhcp_search_sql($conn, $post, $search_sql);
+        if ($ret === 1) {
+            /*MySQL_exec_query*/
+            mysqli_close($conn);
+            return(1);
+        }
+
+        /*MySQL*/
+        $result = MySQL_exec_query($conn, $search_sql);
+        $err_num = 0;
+        if ($result === FALSE) {
+            $err_num = mysqli_errno($conn);
+            mysqli_close($conn);
+            return(2);
+        }
+
+        /*MySQLϿ줿ơ֥ξ˳Ǽ*/
+        MySQL_get_data($result, $data);
+        mysqli_close($conn);
+
+    /* פ "elasticsearch" ξ */
+    } else if ($web_conf['sylas']['searchtype'] === ELASTICSEARCH) {
+
+        /* 롼פ򸡺 */
+        $ret = get_loggroup($conn, $post['loggroup'], $groupdata);
+        mysqli_close($conn);
+
+        /* ƥ२顼(MYSQL³顼) */
+        if ($ret === 2) {
+            result_log(OPERATION . ":NG:" . $log_msg);
+            syserr_display();
+            return(1);
+
+        /* 롼פ¸ߤ */
+        } else if ($ret === 0) {
+
+            $gettype = "dhcp";
+            /* elasticsearchǡ */
+            $elastic_data = get_elasticdata($groupdata, $post, $gettype);
+
+            /* оݤelasticsearchФ³Ǥʤä */
+            if ($elastic_data === FALSE) {
+                $err_msg = sprintf($msgarr['50000'][SCREEN_MSG], LOG_NAME_DISP);
+                $log_msg = sprintf($msgarr['50000'][LOG_MSG], LOG_NAME_LOG);
+                result_log(OPERATION . ":NG:" . $log_msg);
+                syserr_display();
+                exit(1);
+            }
+
+            /* elasticserach֤ͤjsonǥ(Ϣ) */
+            $xmlarr = json_decode($elastic_data);
+            /* jsonǥɤɬפͤ */
+            $data = extract_values($xmlarr);
+
+            /* Ի */
+            if ($data === false) {
+                return(1);
+            }
+        }
+    }
 
     $result = array();
     $max = count($data);
@@ -487,7 +538,6 @@ if (isset($_POST["search_button"])) {
         /* 롼ץκ */
         set_loop_tag($result, $page, $looptag, $sesskey, $post, $i);
 
-        /* ݻhidden */
     }
 } 
 
