@@ -295,7 +295,7 @@ function set_loop_tag($page, &$looptag, $sesskey, $post)
             $looptag[$k]["<<E_SH>>"] = "--";
             $looptag[$k]["<<E_SMI>>"] = "--";
             $looptag[$k]["<<E_SS>>"] = "--";
-            $looptag[$k]["<<QID>>"] = $_SESSION["result"][$start]["qid"];
+            $looptag[$k]["<<QID>>"] = $_SESSION["result"][$start]["qid"]. ":";
         } else {
 
             $half_date = explode(" ", $log_date);
@@ -778,22 +778,27 @@ function exec_mail_search($post)
 
         /*Ծ׽*/
         if ($post["sendaddr"] !== "") {
+            $lpaddr = strtolower($post["sendaddr"]);
+            $lladdr = strtolower($val1["from"]);
+
             if ($post["sendrule"] === "0") {
-                if ($post["sendaddr"] !== $val1["from"]) {
+                if ($lpaddr !== $lladdr) {
                      continue;
                 }
-            } elseif (strstr($val1["from"], $post["sendaddr"]) === FALSE) {
+            } elseif (strstr($lladdr, $lpaddr) === FALSE) {
                 continue;
             }
         }
  
         /*׽*/
         if ($post["reciveaddr"] !== "") {
+            $lpaddr = strtolower($post["reciveaddr"]);
+            $lladdr = strtolower($val1["to"]);
             if ($post["reciverule"] === "0") {
-                if ($post["reciveaddr"] !== $val1["to"]) {
+                if ($lpaddr !== $lladdr) {
                     continue;
                 }
-            } elseif (strstr($val1["to"], $post["reciveaddr"]) === FALSE) {
+            } elseif (strstr($lladdr, $lpaddr) === FALSE) {
                 continue;
             }
         }
